<?php
/**
 * Demo Deployer Module
 *
 * @version		1.2.0
 * @author		Martin Rasser, Elovaris Web Development
 * @copyright	Copyright (C) 2009 Elovaris Web Development. All rights reserved.
 * @license		MIT license (http://www.opensource.org/licenses/mit-license.php) or GNU/GPL (http://www.gnu.org/licenses/gpl-2.0.html)
 */
defined('_JEXEC') or die('Restricted access');
?>
<div class="mod_demodeployer <?php echo $params->get('moduleclass_sfx');?>">
	
	<div class="form-content">
	
		<p><?php echo $params->get('teaser_text');?></p>
		<form action="<?php echo $params->get('url');?>" method="get">
			<div>
				<label for="demo_name"><?php echo $params->get('label_name');?></label>
				<input type="text" id="demo_name" name="demo_name" />
				
				<label for="demo_email"><?php echo $params->get('label_email');?></label>
				<input type="text" id="demo_email" name="demo_email" />
				
				<input type="hidden" id="demo_language" name="demo_language" value="<?php echo JFactory::getLanguage()->getTag();?>" />
				<input type="submit" class="submit-button" value="<?php echo $params->get('button_text');?>" />
				<img class="loading-symbol" src="modules/mod_demodeployer/assets/images/ajax-loader.gif" alt="<?php echo JText::_('Loading');?>" />
			</div>
		</form>
		
		<div class="wait-text"></div>
	
	</div>
	
	<div class="response-text"></div>

</div>

<?php
ob_start();
?>
<script type="text/javascript">
//<![CDATA[

try {
	
	jQuery(document).ready(function(){		
		
		jQuery('.mod_demodeployer form').submit(function(event) {
			
			// Collect and sanitize form data
			var formData = {
				name 		: jQuery.trim( jQuery('#demo_name').val() ),
				email 		: jQuery.trim( jQuery('#demo_email').val() ),
				language 	: jQuery.trim( jQuery('#demo_language').val() )
			};
	
			DemoDeployer.startDemoRequest(event, formData);
	
		});
		
		
	});

} catch (e) {

	if (typeof(jQuery) == "undefined") {
		alert('The demo deployer module (mod_demodeployer) requires jQuery.');
	}
	else {
		alert("An error occured when loading the mod_demodeployer JavaScript code. The message was: \n\n" + e.message);
	}
	
}

var DemoDeployer = {
	
	waitText				: '<?php echo addslashes( $params->get('wait_text','') );?>',
	validationMissingText 	: '<?php echo addslashes( $params->get('validation_missing','') );?>',
	validationEmailText 	: '<?php echo addslashes( $params->get('validation_email','') );?>',
	creationFailureText 	: '<?php echo addslashes( $params->get('creation_failure',''));?>',
	requestUrl				: "<?php echo addslashes( $params->get('url',''));?>",

	eventTrackingCategoryName 		: '<?php echo $params->get("event_tracking_category","demos");?>',
	eventTrackingActionNameSuccess 	: '<?php echo $params->get("event_tracking_action_success","success");?>',
	eventTrackingActionNameFailure 	: '<?php echo $params->get("event_tracking_action_failure","failure");?>',

	demoRequested : false,
	
	startDemoRequest : function(event, formData) {

		// Do not actually send the form data
		event.preventDefault();
		event.stopPropagation();

		// Lock this functionality if request was already made
		if ( this.demoRequested == true ) {
			return;
		}
		this.demoRequested = true;
		
		// Store form data
		this.formData = formData;
		
		// Validate form data
		if (this.validateFormData(this.formData) == false) {
			return false;
		}

		// Disable all form elements
		jQuery('.mod_demodeployer input').attr('disabled',true);
		
		// Show loading symbol
		jQuery('.mod_demodeployer .loading-symbol').fadeIn(100);

		// Display wait text
		jQuery('.mod_demodeployer .wait-text').html(this.waitText).fadeIn(100);

		// Send the demo request
		jQuery.ajax({
			
			url				: this.requestUrl,
			dataType		: 'jsonp',
			data			: this.formData,
			crossDomain		: true,
			success			: this.showSuccessResponse,
			error			: this.showFailureRespone,
			complete		: this.onComplete,
			
			statusCode: {
				404: this.showFailureResponse,
				500: this.showFailureResponse
			}

		});
	},
	
	showSuccessResponse : function(data) {

		// Write response
		jQuery('.mod_demodeployer .response-text').html(data.feedback);

		// Track success event
		if (typeof(_gaq) != 'undefined') {
			_gaq.push(['_trackEvent', this.eventTrackingCategoryName, this.eventTrackingActionNameSuccess , this.formData.email ]);
		}
		
		
	},

	showFailureResponse : function(data) {

		// Write response
		jQuery('.mod_demodeployer .response-text').html(this.creationFailureText);

		// Track failure event
		if (typeof(_gaq) != 'undefined') {
			_gaq.push(['_trackEvent', this.eventTrackingCategoryName , this.eventTrackingActionNameFailure , this.formData.email]);
		}

	},

	onComplete : function(data) {

		// Remove the loading symbol
		jQuery('.mod_demodeployer .loading-symbol').fadeOut(100);

		// Re-enable all form inputs
		jQuery('.mod_demodeployer input').attr('disabled',false);
		
		// Slide up the form and show the response content
		jQuery('.mod_demodeployer .form-content').slideUp(200, function() {
			jQuery('.mod_demodeployer .response-text').fadeIn(200);
		});
	},

	validateFormData : function (formData) {
		
		// Check for missing entries
		if ( formData.name == '' || formData.email == '') {
			alert(DemoDeployer.validationMissingText);
			return false;
		}

		// Check for an invalid e-mail address
		var reg = /^([A-Za-z0-9_\-\.])+\@([A-Za-z0-9_\-\.])+\.([A-Za-z]{2,4})$/;
		if(reg.test(formData.email) == false) {
			alert(DemoDeployer.validationEmailText);
			return false;
		}

		return true;
	}
}
//]]>
</script>

<?php
$js = ob_get_clean();
$doc = JFactory::getDocument();
$doc->addCustomTag($js);

ob_start();
?>

.mod_demodeployer label {
	display:block;	
}

.mod_demodeployer input[type=text] {
	margin-bottom:5px;
	width:180px;
}

.mod_demodeployer .submit-button {
	margin-right:5px;
	margin-top:5px;
}

.mod_demodeployer form {
	margin-top:10px;
}

.mod_demodeployer .wait-text {
	display:none;
	margin:5px 0px;
}

.mod_demodeployer .loading-symbol {
	display:none;
	position:relative;
	top:4px;
}

<?php 
$css = ob_get_clean();
$doc = JFactory::getDocument();
$doc->addStyleDeclaration($css);
?>